=== modified file 'README.txt'
--- README.txt	2009-03-10 01:05:08 +0000
+++ README.txt	2009-03-17 22:31:42 +0000
@@ -11,15 +11,19 @@
 GETTING STARTED
 ---------------
 
-Loggerhead depends on 
+Loggerhead depends on:
+
 1) SimpleTAL for templating.
-   on Ubuntu package `sudo apt-get install python-simpletal`
+   On Ubuntu, `sudo apt-get install python-simpletal`
    or download from http://www.owlfish.com/software/simpleTAL/download.html
-2) Paste for the server. (You need version 1.2 or newer of Paste.) 
-   on Ubuntu package `sudo apt-get install python-paste`
+2) simplejson for producing JSON data.
+   On Ubuntu, `sudo apt-get install python-simplejson`
+   or use `easy_install simplejson`.
+3) Paste for the server. (You need version 1.2 or newer of Paste.)
+   On Ubuntu, `sudo apt-get install python-paste`
    or use `easy_install Paste`
-3) Paste Deploy  (optional, needed when proxying through Apache)
-   on Ubuntu package `sudo apt-get install python-pastedeploy`
+4) Paste Deploy  (optional, needed when proxying through Apache)
+   On Ubuntu, `sudo apt-get install python-pastedeploy`
    or use `easy_install PasteDeploy`
 
 Then simply run the 'serve-branches' with the branch you want to

=== modified file 'loggerhead/controllers/changelog_ui.py'
--- loggerhead/controllers/changelog_ui.py	2009-03-16 23:01:40 +0000
+++ loggerhead/controllers/changelog_ui.py	2009-03-17 22:38:57 +0000
@@ -17,9 +17,13 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-import simplejson
 import urllib
 
+try:
+    import simplejson
+except ImportError:
+    import json as simplejson
+
 from paste.httpexceptions import HTTPServerError
 
 from loggerhead import util

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2009-03-06 20:43:13 +0000
+++ loggerhead/history.py	2009-03-16 23:21:29 +0000
@@ -564,10 +564,15 @@
 
         message, short_message = clean_message(revision.message)
 
+        try:
+            authors = revision.get_apparent_authors()
+        except AttributeError:
+            authors = [revision.get_apparent_author()]
+
         entry = {
             'revid': revision.revision_id,
             'date': commit_time,
-            'author': revision.get_apparent_author(),
+            'authors': authors,
             'branch_nick': revision.properties.get('branch-nick', None),
             'short_comment': short_message,
             'comment': revision.message,

=== modified file 'loggerhead/templates/annotate.pt'
--- loggerhead/templates/annotate.pt	2009-03-02 00:10:26 +0000
+++ loggerhead/templates/annotate.pt	2009-03-06 09:57:54 +0000
@@ -65,7 +65,7 @@
               <a tal:condition="python:line.status=='changed'"
                  tal:content="python:util.trunc(line.change.revno)"
                  tal:attributes="href python:url(['/revision', line.change.revno], clear=1);
-                                 title python:'%s by %s, on %s (%s)'%(line.change.revno, util.hide_email(line.change.author), line.change.date.strftime('%d %b %Y %H:%M'), util.date_time(line.change.date))"></a>
+                                 title python:'%s by %s, on %s (%s)'%(line.change.revno, ', '.join(util.hide_emails(line.change.authors)), line.change.date.strftime('%d %b %Y %H:%M'), util.date_time(line.change.date))"></a>
             </td>
             <td class="annoCont"><pre tal:content="structure line/text"></pre></td>
           </tr>

=== modified file 'loggerhead/templates/atom.pt'
--- loggerhead/templates/atom.pt	2008-06-26 20:42:15 +0000
+++ loggerhead/templates/atom.pt	2009-03-06 09:57:54 +0000
@@ -17,8 +17,8 @@
     <id tal:content="python:branch.url(['/revision', entry.revno])">
       ID
     </id>
-    <author>
-      <name tal:content="python:util.hide_email(entry.author)">
+    <author tal:repeat="author entry/authors">
+      <name tal:content="python:util.hide_email(author)">
         author
       </name>
     </author>

=== modified file 'loggerhead/templates/changelog.pt'
--- loggerhead/templates/changelog.pt	2009-03-16 03:05:49 +0000
+++ loggerhead/templates/changelog.pt	2009-03-16 23:21:29 +0000
@@ -72,7 +72,7 @@
           <td class="revisionnumber">Rev</td>
           <td class="expandcell show_if_js">&nbsp;</td>
           <td class="summarycell">Summary</td>
-          <td class="authorcell">Author</td>
+          <td class="authorcell">Authors</td>
           <td class="datecell">Date</td>
           <td class="diffcell">Diff</td>
           <td class="downloadcell">Files</td>
@@ -120,7 +120,7 @@
                 </div>
               </div>
             </td>
-            <td tal:content="python:util.trunc(util.hide_email(entry.author), 20)"
+            <td tal:content="python:util.trunc(util.hide_email(entry.authors[0]), 20)"
                 class="autcell"></td>
             <td class="date">
               <span tal:attributes="title python:util.date_time(entry.date)"

=== modified file 'loggerhead/templates/revisioninfo.pt'
--- loggerhead/templates/revisioninfo.pt	2009-03-17 06:32:25 +0000
+++ loggerhead/templates/revisioninfo.pt	2009-03-18 04:52:57 +0000
@@ -1,6 +1,6 @@
 <div class="infoContainer">
     <div id="infTxt">
-        <div class="committer" tal:content="python:util.hide_email(change.author)"></div>
+        <div class="committer" tal:content="python:', '.join(util.hide_emails(change.authors))"></div>
         <div class="timer" tal:content="python:util.date_time(change.date)"></div>
         <div class="mfrom" tal:repeat="parent python:change.parents[1:]">
             <a tal:attributes="title string:Merged From ${parent/revno};

=== modified file 'loggerhead/templates/revlog.pt'
--- loggerhead/templates/revlog.pt	2009-03-13 05:36:26 +0000
+++ loggerhead/templates/revlog.pt	2009-03-16 23:30:18 +0000
@@ -15,7 +15,7 @@
          tal:content="python:revno_with_nick(merge_point)"
          title="Show history" class="link"></a>
     </li>
-    <li class="committerli" tal:content="python:util.hide_email(entry.author)"></li>
+    <li class="committerli" tal:content="python:', '.join(util.hide_emails(entry.authors))"></li>
     <tal:block content="structure python:file_change_summary(url, entry)" />
   </ul>
 </div>

=== modified file 'loggerhead/util.py'
--- loggerhead/util.py	2009-03-03 21:39:54 +0000
+++ loggerhead/util.py	2009-03-06 09:57:54 +0000
@@ -181,6 +181,14 @@
         return '%s at %s' % (username, domains[-2])
     return '%s at %s' % (username, domains[0])
 
+def hide_emails(emails):
+    """
+    try to obscure any email address in a list of bazaar committers' names.
+    """
+    result = []
+    for email in emails:
+        result.append(hide_email(email))
+    return result
 
 # only do this if unicode turns out to be a problem
 #_BADCHARS_RE = re.compile(ur'[\u007f-\uffff]')

